Wrappers for host and guest functions.
Structs
- Host
Function - Re-export for
HostFunctiontrait A representation of a host function. This is a thin wrapper around aFn(Args) -> Result<Output>. - Host
Function Definition - Re-export for
HostFunctionDefinitionThe definition of a function exposed from the host to the guest - Host
Function Details - Re-export for
HostFunctionDetailsHostFunctionDetailsrepresents the set of functions that the host exposes to the guest.
Enums
- Parameter
Type - Re-export for
ParameterTypeenum Supported parameter types for function calling. - Parameter
Value - Re-export for
ParameterValueenum Supported parameter types with values for function calling. - Return
Type - Re-export for
ReturnTypeenum Supported return types from function calling. - Return
Value - Re-export for
ReturnValueenum Supported return types with values from function calling.
Traits
- Parameter
Tuple - A trait to describe the tuple of parameters that a host function can take.
- Registerable
- Re-export for
HostFunctiontrait A sandbox on which (primitive) host functions can be registered - Result
Type - A trait to handle either a
SupportedReturnTypeor aResult<impl SupportedReturnType> - Supported
Parameter Type - This is a marker trait that is used to indicate that a type is a valid Hyperlight parameter type.
- Supported
Return Type - This is a marker trait that is used to indicate that a type is a valid Hyperlight return type.