Module mem

Module mem 

Functionality to establish and manage an individual sandbox’s memory.

  • Virtual Address

0x0000 PML4 0x1000 PDPT 0x2000 PD 0x3000 The guest PE code (When the code has been loaded using LoadLibrary to debug the guest this will not be present and code length will be zero;

  • The pointer passed to the Entrypoint in the Guest application is the size of page table + size of code, at this address structs below are laid out in this order

Modules

layout
Functionality to establish a sandbox’s memory layout. This module describes the virtual and physical addresses of a number of special regions in the hyperlight VM, although we hope to reduce the number of these over time.
memory_region
memory regions to be mapped inside a vm
mgr
Functionality that wraps a SandboxMemoryLayout and a SandboxMemoryConfig to mutate a sandbox’s memory as necessary.
ptr
Structures to represent pointers into guest and host memory
ptr_offset
Structures to represent an offset into a memory space
shared_mem
A wrapper around unsafe functionality to create and initialize a memory region for a guest running in a sandbox.