Module memory_region

Module memory_region 

memory regions to be mapped inside a vm

Structs

HostGuestMemoryRegion
Type for memory regions that track both host and guest addresses.
MemoryRegionFlags
flags representing memory permission for a memory region
MemoryRegion_
represents a single memory region inside the guest. All memory within a region has the same memory permissions

Enums

MemoryRegionType
The type of memory region

Traits

MemoryRegionKind
A trait that distinguishes between different kinds of memory region representations.

Type Aliases

MemoryRegion
A memory region that tracks both host and guest addresses.