pub enum StackError {
SpOob(StackOp, usize, usize),
CorruptBackPointer(usize, usize),
OverflowingPrefix(u32),
PrefixTooLarge(TryFromIntError),
CorruptPrefix(usize, usize),
ConvertError(String),
BufferFullError(usize, usize),
}Expand description
An error related to the stack discipline of guest I/O
Variants
SpOob(StackOp, usize, usize)
The stack pointer for a stack entry was out-of-bounds for the stack
CorruptBackPointer(usize, usize)
The back pointer for a stack entry was corrupt
OverflowingPrefix(u32)
A stack entry size prefix was too large for necessary operations on it to remain in the range of a u32
PrefixTooLarge(TryFromIntError)
It was not possible to convert a stack entry size prefix into a usize. This should be impossible on all currently supported architectures, since usize is 64 bits on all of them.
CorruptPrefix(usize, usize)
A stack entry size prefix is larger than its logically-enclosing element
ConvertError(String)
An error was encountered during a routine error conversion that should have been infallible
BufferFullError(usize, usize)
There was not enough free space available on the stack for an element to be pushed