pub enum StackOp {
Push,
Pop,
}Expand description
Whether a StackError was encountered whilst pushing or popping
from the guest stack
Variants
Push
The error was encountered while pushing to the guest stack
Pop
The error was encountered while popping from the guest stack