pub struct GuestSharedMemory {
pub lock: Arc<RwLock<()>>,
/* private fields */
}Expand description
A GuestSharedMemory is used by the hypervisor handler to represent the reference to all-of-memory that is taken by the virtual cpu. Because of the memory model limitations that affect HostSharedMemory, it is likely fairly important (to ensure that our UB remains limited to interaction with an external compilation unit that likely can’t be discovered by the compiler) that rust users do not perform racy accesses to the guest communication buffers that are also accessed by HostSharedMemory.
Fields
lock: Arc<RwLock<()>>The lock that indicates this shared memory is being used by non-Rust code