ReadonlySharedMemory

Struct ReadonlySharedMemory 

pub struct ReadonlySharedMemory { /* private fields */ }
A ReadonlySharedMemory is a different kind of shared memory, separate from the exclusive/host/guest lifecycle, used to represent read-only mappings of snapshot pages into the guest efficiently.