Module initialized_multi_use

Module initialized_multi_use 

Functionality for dealing with initialized sandboxes that can call 0 or more guest functions

Structs

MultiUseSandbox
A fully initialized sandbox that can execute guest function calls.

Enums

SandboxStatus
The lifecycle state of a MultiUseSandbox.

Type Aliases

PtRootFinder
Callback for discovering page table roots from guest memory.