pub struct OciTag(/* private fields */);Expand description
A tag naming one snapshot inside an OCI Image Layout directory. Used to save a snapshot under a name and to load it back by that same name.
Implementations