Context structures used to allow the user to call one or more guest functions on the same Hyperlight sandbox instance, all from within the same state and mutual exclusion context.
Structs
- Multi
UseGuest Call Context - A context for calling guest functions.
- Single
UseGuest Call Context - A context for calling guest functions. Can only be created from an existing
SingleUseSandbox, and once created, guest functions against that sandbox can be made from this until it is dropped. - Single
UseMulti Guest Call Context - A context for making multiple calls to guest functions in a SingleUseSandbox. Can only be created
from an existing SingleUseGuestCallContext using the
call_using_closuremethod. Once created, calls to guest functions may be made through this context until it is dropped. Once dropped the underlyingSingleUseGuestCallContextand associatedSingleUseSandboxwill be dropped