memory regions to be mapped inside a vm
Structs
- Host
Guest Memory Region - Type for memory regions that track both host and guest addresses.
- Memory
Region Flags - flags representing memory permission for a memory region
- Memory
Region_ - represents a single memory region inside the guest. All memory within a region has the same memory permissions
Enums
- Memory
Region Type - The type of memory region
Traits
- Memory
Region Kind - A trait that distinguishes between different kinds of memory region representations.
Type Aliases
- Memory
Region - A memory region that tracks both host and guest addresses.