pub enum SharedMemoryError {
Bounds(usize, usize, usize),
FileMetadata(Error),
FileTooLarge(TryFromIntError),
LockError(String, Backtrace),
MemoryAllocationFailed(Option<i32>),
MemoryRequest(usize, usize, usize, usize),
MmapFailed(Option<i32>),
MprotectFailed(Option<i32>),
ReadonlySharedMemoryExclusiveRequest,
Stack(StackError),
TryFromSlice(TryFromSliceError),
TryFromInt(TryFromIntError),
}Expand description
An error encountered while setting up or manipulating a shared memory region
Variants
Bounds(usize, usize, usize)
Some operation on the shared memory attempted to read or write out of bounds
FileMetadata(Error)
When creating a memory with contents from a file, metadata for that file could not be read
FileTooLarge(TryFromIntError)
When creating a memory with contents from a file, that file was logically larger than the range of a usize.
LockError(String, Backtrace)
The locking discipline used to enforce temporary exclusive access by the host to a shared memory failed in some way
MemoryAllocationFailed(Option<i32>)
A request to allocate a shared memory could not be fulfilled by the host operating system
MemoryRequest(usize, usize, usize, usize)
A ruqest to allocate a shared shared memory had an invalid size, due either to bounds or alignment.
MmapFailed(Option<i32>)
An request to mmap a file or create an anonymous memory could not be fulfilled by the host operating system
MprotectFailed(Option<i32>)
A request to change the host-side permissions on the guard pages of a shared memory region could not be fulfilled by the host operating system
Calling code attempted to take exclusive (write) access to a
ReadonlySharedMemory.
Stack(StackError)
The stack discipline of guest I/O was violated in some way
TryFromSlice(TryFromSliceError)
An error was encountered when trying to convert a slice of raw bytes into some logical data
TryFromInt(TryFromIntError)
An error was encountered during a routine error conversion that should have been infallible