Functionality for dealing with initialized sandboxes that can call 0 or more guest functions
Structs
- Multi
UseSandbox - A fully initialized sandbox that can execute guest function calls.
Enums
- Sandbox
Status - The lifecycle state of a
MultiUseSandbox.
Type Aliases
- PtRoot
Finder - Callback for discovering page table roots from guest memory.