pub enum NextAction {
Initialise(u64),
Call(u64),
}Expand description
Presently, a snapshot can be of a preinitialised sandbox, which still needs an initialise function called in order to determine how to call into it, or of an already-properly-initialised sandbox which can be immediately called into. This keeps track of the difference.
TODO: this should not necessarily be around in the long term: ideally we would just preinitialise earlier in the snapshot creation process and never need this.
Variants
Initialise(u64)
A sandbox in the preinitialise state still needs to be initialised by calling the initialise function
Call(u64)
A sandbox in the ready state can immediately be called into, using the dispatch function pointer.