pub enum GuestBinary<'a> {
Buffer(&'a [u8]),
FilePath(String),
}Expand description
A GuestBinary is either a buffer or the file path to some data (e.g., a guest binary).
Variants
Implementations
Sourceimpl<'a> GuestBinary<'a>
impl<'a> GuestBinary<'a>
Sourcepub fn canonicalize(&mut self) -> Result<()>
pub fn canonicalize(&mut self) -> Result<()>
If the guest binary is identified by a file, canonicalise the path
For GuestBinary::FilePath, this resolves the path to its canonical
form. For GuestBinary::Buffer, this method is a no-op.
TODO: Maybe we should make the GuestEnvironment or
GuestBinary constructors crate-private and turn this
into an invariant on one of those types.