pub struct GuestEnvironment<'b> {
pub guest_binary: GuestBinary,
pub init_data: Option<GuestBlob<'b>>,
}Expand description
Container for a guest binary and optional initialization data.
This struct combines a guest binary (either from a file or memory buffer) with optional data that will be available to the guest during execution.
The guest binary is owned. 'b is the lifetime of the borrowed init data.
Fields
guest_binary: GuestBinaryThe guest binary, which can be a file path or a buffer.
init_data: Option<GuestBlob<'b>>An optional guest blob, which can be used to provide additional data to the guest.
Implementations
Sourceimpl<'b> GuestEnvironment<'b>
impl<'b> GuestEnvironment<'b>
Sourcepub fn new(guest_binary: GuestBinary, init_data: Option<&'b [u8]>) -> Self
pub fn new(guest_binary: GuestBinary, init_data: Option<&'b [u8]>) -> Self
Creates a new GuestEnvironment with the given guest binary and an optional guest blob.